Pat

Enum Pat 

pub enum Pat {
Show 13 variants Wild(PatWild), Ident(PatIdent), Struct(PatStruct), TupleStruct(PatTupleStruct), Path(PatPath), Tuple(PatTuple), Box(PatBox), Ref(PatRef), Lit(PatLit), Range(PatRange), Slice(PatSlice), Macro(PatMacro), Verbatim(PatVerbatim),
}
A pattern in a local binding, function signature, match expression, or various other places.

This type is available if Syn is built with the "full" feature.

Syntax tree enum

This type is a syntax tree enum.

Variants



Wild(PatWild)

A pattern that matches any value: _.

This type is available if Syn is built with the "full" feature.



Ident(PatIdent)

A pattern that binds a new variable: ref mut binding @ SUBPATTERN.

This type is available if Syn is built with the "full" feature.



Struct(PatStruct)

A struct or struct variant pattern: Variant { x, y, .. }.

This type is available if Syn is built with the "full" feature.



TupleStruct(PatTupleStruct)

A tuple struct or tuple variant pattern: Variant(x, y, .., z).

This type is available if Syn is built with the "full" feature.



Path(PatPath)

A path pattern like Color::Red, optionally qualified with a self-type.

Unquailfied path patterns can legally refer to variants, structs, constants or associated constants. Quailfied path patterns like <A>::B::C and <A as Trait>::B::C can only legally refer to associated constants.

This type is available if Syn is built with the "full" feature.



Tuple(PatTuple)

A tuple pattern: (a, b).

This type is available if Syn is built with the "full" feature.



Box(PatBox)

A box pattern: box v.

This type is available if Syn is built with the "full" feature.



Ref(PatRef)

A reference pattern: &mut (first, second).

This type is available if Syn is built with the "full" feature.



Lit(PatLit)

A literal pattern: 0.

This holds an Expr rather than a Lit because negative numbers are represented as an Expr::Unary.

This type is available if Syn is built with the "full" feature.



Range(PatRange)

A range pattern: 1..=2.

This type is available if Syn is built with the "full" feature.



Slice(PatSlice)

A dynamically sized slice pattern: [a, b, i.., y, z].

This type is available if Syn is built with the "full" feature.



Macro(PatMacro)

A macro in expression position.

This type is available if Syn is built with the "full" feature.



Verbatim(PatVerbatim)

Tokens in pattern position not interpreted by Syn.

This type is available if Syn is built with the "full" feature.