pub enum WherePredicate {
Type(PredicateType),
Lifetime(PredicateLifetime),
Eq(PredicateEq),
}Expand description
A single predicate in a where clause: T: Deserialize<'de>.
This type is available if Syn is built with the "derive" or "full"
feature.
Syntax tree enum
This type is a syntax tree enum.
Variants
Type(PredicateType)
A type predicate in a where clause: for<'c> Foo<'c>: Trait<'c>.
This type is available if Syn is built with the "derive" or
"full" feature.
Lifetime(PredicateLifetime)
A lifetime predicate in a where clause: 'a: 'b + 'c.
This type is available if Syn is built with the "derive" or
"full" feature.
Eq(PredicateEq)
An equality predicate in a where clause (unsupported).
This type is available if Syn is built with the "derive" or
"full" feature.