pub struct ExprBinary {
pub attrs: Vec<Attribute>,
pub left: Box<Expr>,
pub op: BinOp,
pub right: Box<Expr>,
}Expand description
A binary operation: a + b, a * b.
This type is available if Syn is built with the "derive" or
"full" feature.
Fields
attrs: Vec<Attribute>left: Box<Expr>op: BinOpright: Box<Expr>Trait Implementations
Sourceimpl Clone for ExprBinary
impl Clone for ExprBinary
Sourcefn clone(&self) -> ExprBinary
fn clone(&self) -> ExprBinary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprBinary
impl Debug for ExprBinary
impl Eq for ExprBinary
Sourceimpl From<ExprBinary> for Expr
impl From<ExprBinary> for Expr
Sourcefn from(e: ExprBinary) -> Expr
fn from(e: ExprBinary) -> Expr
Converts to this type from the input type.
Sourceimpl Hash for ExprBinary
impl Hash for ExprBinary
Sourceimpl PartialEq for ExprBinary
impl PartialEq for ExprBinary
Sourcefn eq(&self, other: &ExprBinary) -> bool
fn eq(&self, other: &ExprBinary) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExprBinary