pub struct ExprClosure {
pub attrs: Vec<Attribute>,
pub capture: Option<Move>,
pub or1_token: Or,
pub inputs: Punctuated<FnArg, Comma>,
pub or2_token: Or,
pub output: ReturnType,
pub body: Box<Expr>,
}Expand description
A closure expression: |a, b| a + b.
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>capture: Option<Move>or1_token: Orinputs: Punctuated<FnArg, Comma>or2_token: Oroutput: ReturnTypebody: Box<Expr>Trait Implementations
Sourceimpl Clone for ExprClosure
impl Clone for ExprClosure
Sourcefn clone(&self) -> ExprClosure
fn clone(&self) -> ExprClosure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprClosure
impl Debug for ExprClosure
impl Eq for ExprClosure
Sourceimpl From<ExprClosure> for Expr
impl From<ExprClosure> for Expr
Sourcefn from(e: ExprClosure) -> Expr
fn from(e: ExprClosure) -> Expr
Converts to this type from the input type.
Sourceimpl Hash for ExprClosure
impl Hash for ExprClosure
Sourceimpl PartialEq for ExprClosure
impl PartialEq for ExprClosure
Sourcefn eq(&self, other: &ExprClosure) -> bool
fn eq(&self, other: &ExprClosure) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExprClosure