pub struct ExprMethodCall {
pub attrs: Vec<Attribute>,
pub receiver: Box<Expr>,
pub dot_token: Dot,
pub method: Ident,
pub turbofish: Option<MethodTurbofish>,
pub paren_token: Paren,
pub args: Punctuated<Expr, Comma>,
}Expand description
A method call expression: x.foo::<T>(a, b).
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>receiver: Box<Expr>dot_token: Dotmethod: Identturbofish: Option<MethodTurbofish>paren_token: Parenargs: Punctuated<Expr, Comma>Trait Implementations
Sourceimpl Clone for ExprMethodCall
impl Clone for ExprMethodCall
Sourcefn clone(&self) -> ExprMethodCall
fn clone(&self) -> ExprMethodCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprMethodCall
impl Debug for ExprMethodCall
impl Eq for ExprMethodCall
Sourceimpl From<ExprMethodCall> for Expr
impl From<ExprMethodCall> for Expr
Sourcefn from(e: ExprMethodCall) -> Expr
fn from(e: ExprMethodCall) -> Expr
Converts to this type from the input type.
Sourceimpl Hash for ExprMethodCall
impl Hash for ExprMethodCall
Sourceimpl PartialEq for ExprMethodCall
impl PartialEq for ExprMethodCall
Sourcefn eq(&self, other: &ExprMethodCall) -> bool
fn eq(&self, other: &ExprMethodCall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExprMethodCall