pub struct ExprRepeat {
pub attrs: Vec<Attribute>,
pub bracket_token: Bracket,
pub expr: Box<Expr>,
pub semi_token: Semi,
pub len: Box<Expr>,
}Expand description
An array literal constructed from one repeated element: [0u8; N].
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>bracket_token: Bracketexpr: Box<Expr>semi_token: Semilen: Box<Expr>Trait Implementations
Sourceimpl Clone for ExprRepeat
impl Clone for ExprRepeat
Sourcefn clone(&self) -> ExprRepeat
fn clone(&self) -> ExprRepeat
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprRepeat
impl Debug for ExprRepeat
impl Eq for ExprRepeat
Sourceimpl From<ExprRepeat> for Expr
impl From<ExprRepeat> for Expr
Sourcefn from(e: ExprRepeat) -> Expr
fn from(e: ExprRepeat) -> Expr
Converts to this type from the input type.
Sourceimpl Hash for ExprRepeat
impl Hash for ExprRepeat
Sourceimpl PartialEq for ExprRepeat
impl PartialEq for ExprRepeat
Sourcefn eq(&self, other: &ExprRepeat) -> bool
fn eq(&self, other: &ExprRepeat) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExprRepeat
Sourceimpl Synom for ExprRepeat
Available on crate feature full only.
impl Synom for ExprRepeat
Available on crate feature
full only.Auto Trait Implementations
impl !Send for ExprRepeat
impl !Sync for ExprRepeat
impl Freeze for ExprRepeat
impl RefUnwindSafe for ExprRepeat
impl Unpin for ExprRepeat
impl UnsafeUnpin for ExprRepeat
impl UnwindSafe for ExprRepeat