pub struct ExprWhileLet {
pub attrs: Vec<Attribute>,
pub label: Option<Label>,
pub while_token: While,
pub let_token: Let,
pub pat: Box<Pat>,
pub eq_token: Eq,
pub expr: Box<Expr>,
pub body: Block,
}Expand description
A while-let loop: while let pat = expr { ... }.
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>label: Option<Label>while_token: Whilelet_token: Letpat: Box<Pat>eq_token: Eqexpr: Box<Expr>body: BlockTrait Implementations
Sourceimpl Clone for ExprWhileLet
impl Clone for ExprWhileLet
Sourcefn clone(&self) -> ExprWhileLet
fn clone(&self) -> ExprWhileLet
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprWhileLet
impl Debug for ExprWhileLet
impl Eq for ExprWhileLet
Sourceimpl From<ExprWhileLet> for Expr
impl From<ExprWhileLet> for Expr
Sourcefn from(e: ExprWhileLet) -> Expr
fn from(e: ExprWhileLet) -> Expr
Converts to this type from the input type.
Sourceimpl Hash for ExprWhileLet
impl Hash for ExprWhileLet
Sourceimpl PartialEq for ExprWhileLet
impl PartialEq for ExprWhileLet
Sourcefn eq(&self, other: &ExprWhileLet) -> bool
fn eq(&self, other: &ExprWhileLet) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExprWhileLet
Sourceimpl Synom for ExprWhileLet
Available on crate feature full only.
impl Synom for ExprWhileLet
Available on crate feature
full only.Auto Trait Implementations
impl !Send for ExprWhileLet
impl !Sync for ExprWhileLet
impl Freeze for ExprWhileLet
impl RefUnwindSafe for ExprWhileLet
impl Unpin for ExprWhileLet
impl UnsafeUnpin for ExprWhileLet
impl UnwindSafe for ExprWhileLet