PatPath

Struct PatPath 

pub struct PatPath {
    pub qself: Option<QSelf>,
    pub path: Path,
}
A path pattern like Color::Red, optionally qualified with a self-type.

Unquailfied path patterns can legally refer to variants, structs, constants or associated constants. Quailfied path patterns like <A>::B::C and <A as Trait>::B::C can only legally refer to associated constants.

This type is available if Syn is built with the "full" feature.

Fields

qself: Option<QSelf>path: Path