pub struct TypeImplTrait {
pub impl_token: Impl,
pub bounds: Punctuated<TypeParamBound, Add>,
}Expand description
An impl Bound1 + Bound2 + Bound3 type where Bound is a trait or
a lifetime.
This type is available if Syn is built with the "derive" or
"full" feature.
Fields
impl_token: Implbounds: Punctuated<TypeParamBound, Add>Trait Implementations
Sourceimpl Clone for TypeImplTrait
impl Clone for TypeImplTrait
Sourcefn clone(&self) -> TypeImplTrait
fn clone(&self) -> TypeImplTrait
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeImplTrait
impl Debug for TypeImplTrait
impl Eq for TypeImplTrait
Sourceimpl From<TypeImplTrait> for Type
impl From<TypeImplTrait> for Type
Sourcefn from(e: TypeImplTrait) -> Type
fn from(e: TypeImplTrait) -> Type
Converts to this type from the input type.
Sourceimpl Hash for TypeImplTrait
impl Hash for TypeImplTrait
Sourceimpl PartialEq for TypeImplTrait
impl PartialEq for TypeImplTrait
Sourcefn eq(&self, other: &TypeImplTrait) -> bool
fn eq(&self, other: &TypeImplTrait) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TypeImplTrait
Sourceimpl Synom for TypeImplTrait
impl Synom for TypeImplTrait