pub struct TypeReference {
pub and_token: And,
pub lifetime: Option<Lifetime>,
pub mutability: Option<Mut>,
pub elem: Box<Type>,
}Expand description
A reference type: &'a T or &'a mut T.
This type is available if Syn is built with the "derive" or
"full" feature.
Fields
and_token: Andlifetime: Option<Lifetime>mutability: Option<Mut>elem: Box<Type>Trait Implementations
Sourceimpl Clone for TypeReference
impl Clone for TypeReference
Sourcefn clone(&self) -> TypeReference
fn clone(&self) -> TypeReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeReference
impl Debug for TypeReference
impl Eq for TypeReference
Sourceimpl From<TypeReference> for Type
impl From<TypeReference> for Type
Sourcefn from(e: TypeReference) -> Type
fn from(e: TypeReference) -> Type
Converts to this type from the input type.
Sourceimpl Hash for TypeReference
impl Hash for TypeReference
Sourceimpl PartialEq for TypeReference
impl PartialEq for TypeReference
Sourcefn eq(&self, other: &TypeReference) -> bool
fn eq(&self, other: &TypeReference) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TypeReference
Sourceimpl Synom for TypeReference
impl Synom for TypeReference