pub struct VisRestricted {
pub pub_token: Pub,
pub paren_token: Paren,
pub in_token: Option<In>,
pub path: Box<Path>,
}Expand description
A visibility level restricted to some path: pub(self) or
pub(super) or pub(in some::module).
This type is available if Syn is built with the "derive" or
"full" feature.
Fields
pub_token: Pubparen_token: Parenin_token: Option<In>path: Box<Path>Trait Implementations
Sourceimpl Clone for VisRestricted
impl Clone for VisRestricted
Sourcefn clone(&self) -> VisRestricted
fn clone(&self) -> VisRestricted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VisRestricted
impl Debug for VisRestricted
impl Eq for VisRestricted
Sourceimpl From<VisRestricted> for Visibility
impl From<VisRestricted> for Visibility
Sourcefn from(e: VisRestricted) -> Visibility
fn from(e: VisRestricted) -> Visibility
Converts to this type from the input type.
Sourceimpl Hash for VisRestricted
impl Hash for VisRestricted
Sourceimpl PartialEq for VisRestricted
impl PartialEq for VisRestricted
Sourcefn eq(&self, other: &VisRestricted) -> bool
fn eq(&self, other: &VisRestricted) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VisRestricted